==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/models/cms_bind_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../spec_helper'

describe CmsBind do
  fixtures :cms_projects, :cms_pages, :cms_page_titles, 
    :cms_binds, :cms_bind_items, :cms_bind_contents, 
    :cms_templates, :cms_template_contents

  describe "set_bind_name" do
    it 'バインド名をセット' do
      cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles, :cms_project])
      cms_page.bind_center.set_bind_name
      cms_page.bind_center.items.map{|item| item.name}.sort.should == ["おすすめコメント", "店舗住所", "店舗画像"]
    end
  end

  describe "published_filename" do
    describe "cms/show_fashionについて"do
      before(:each) do
        @proj2 = CmsProject.find(2)
        @page = @proj2.pages.find(:first, :conditions => {:controller => 'cms', :action => 'show_fashion'})
      end

      it "中央以外、ページ依存のないテンプレートへのバインド(CmsBindItemがないCmsBind)の場合" do
        bind_bottom = @page.bind_bottom
        bind_bottom.items.should be_empty
        template = bind_bottom.cms_template
        template.should_not be_nil
        template.id.should == 2
        bind_bottom.published_filename(:ja).should     == "cms/_bottom_2009082119101338424900.html.erb"
        bind_bottom.published_filename(:en).should     == "cms/_bottom_2009082119101338424900_en.html.erb"
        bind_bottom.published_filename('zh-CN').should == "cms/_bottom_2009082119101338424900_zh_CN.html.erb"
      end

      it "中央以外、ページ依存のあるテンプレートへのバインド(CmsBindItemを持つCmsBind)の場合" do
        bind_top = @page.bind_top
        bind_top.items.should_not be_empty
        template = bind_top.cms_template
        template.should_not be_nil
        bind_top.published_filename(:ja).should     == "cms/_show_fashion_top.html.erb"
        bind_top.published_filename(:en).should     == "cms/_show_fashion_top_en.html.erb"
        bind_top.published_filename('zh-CN').should == "cms/_show_fashion_top_zh_CN.html.erb"
      end

      it "中央のバインドの場合" do
        bind_center = @page.bind_center
        # bind_center.items.should_not be_empty # itemsの有無はcenterの場合は関係ありません。
        template = bind_center.cms_template
        template.should_not be_nil
        bind_center.published_filename(:ja).should     == "cms/show_fashion.html.erb"
        bind_center.published_filename(:en).should     == "cms/show_fashion_en.html.erb"
        bind_center.published_filename('zh-CN').should == "cms/show_fashion_zh_CN.html.erb"
      end
    end
  end

  describe "filename_map" do
    it "cms/show_fashionについて"do
      @proj2 = CmsProject.find(2)
      @page = @proj2.pages.find(:first, :conditions => {:controller => 'cms', :action => 'show_fashion'})

      # 2009/08/20現在、プロジェクト間で重複するCmsPageは "cms/index"のみ。
      # ただし、オープンされているプロジェクトだけだと重複がないので、全てのステータスを対象にします。
      map = CmsBind.filename_map({:project_status_keys =>[*CmsProject.status_keys]})
      # bottomを利用するページを増やしたため、ファイルの重複が発生しています。よってこのテストはコメントアウトします。
#      map["cms/_bottom_2009082119101338424900.html.erb"      ].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900_en.html.erb"   ].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900_zh_CN.html.erb"].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900.html.erb"      ].last.should == 'ja'
#      map["cms/_bottom_2009082119101338424900_en.html.erb"   ].last.should == 'en'
#      map["cms/_bottom_2009082119101338424900_zh_CN.html.erb"].last.should == 'zh_CN'
      
      map["cms/_show_fashion_top.html.erb"      ].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top_en.html.erb"   ].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top_zh_CN.html.erb"].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top.html.erb"      ].last.should == 'ja'
      map["cms/_show_fashion_top_en.html.erb"   ].last.should == 'en'
      map["cms/_show_fashion_top_zh_CN.html.erb"].last.should == 'zh_CN'
      
      map["cms/show_fashion.html.erb"      ].first.id.should == @page.bind_center.id
      map["cms/show_fashion_en.html.erb"   ].first.id.should == @page.bind_center.id
      map["cms/show_fashion_zh_CN.html.erb"].first.id.should == @page.bind_center.id
      map["cms/show_fashion.html.erb"      ].last.should == 'ja'
      map["cms/show_fashion_en.html.erb"   ].last.should == 'en'
      map["cms/show_fashion_zh_CN.html.erb"].last.should == 'zh_CN'

      page = CmsPage.find(:first, :conditions => {:controller => 'account', :action => 'login'})
      map["account/login.html.erb"      ].first.id.should == page.bind_center.id
      map["account/login_en.html.erb"   ].first.id.should == page.bind_center.id
      map["account/login_zh_CN.html.erb"].first.id.should == page.bind_center.id
      map["account/login.html.erb"      ].last.should == 'ja'
      map["account/login_en.html.erb"   ].last.should == 'en'
      map["account/login_zh_CN.html.erb"].last.should == 'zh_CN'
    end
  
    it "#786 findのオプションを指定可能にします" do
      CmsBind.should_receive(:find).with(:all, 
        :include => [{:cms_template => :contents}, {:cms_page => :titles}, {:items => :contents}],
        :joins => "inner join cms_pages cond_cms_pages on cond_cms_pages.id = cms_binds.cms_page_id ",
        :conditions => ["(cond_cms_pages.id in (?))", CmsPage.primary_page_ids({:project_status_keys => [:opened]})]).
        and_return([])
      
      file_to_bind_in_opened_projects = CmsBind.filename_map({:project_status_keys =>[:opened], 
        :find_options => {:include => [{:cms_template => :contents}, {:cms_page => :titles}, {:items => :contents}]}})
    end

  end

  describe "overwrite" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_pages"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      @cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles])
      @publish = CmsPublish.create!(
        :target => CmsPublish.target_id_by_key(:production),
        :status_cd => CmsPublish.status_id_by_key(:processing),
        :designated_at => 1.minute.ago,
        :default_template_paths => {})
    end

    it "中央" do
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should ==
        '<% content_for(:layout_top) do -%><%= render(:partial => "cms/show_fashion_top") %><% end -%>' <<
        '<% content_for(:layout_bottom) do -%><%= render(:partial => "cms/bottom_2009082119101338424900") %><% end -%>' <<
        "夏物入荷しました！！ja\n<%= ec.shop_address -%>\n<%= ec.shop_logo -%>"
    end

    it "上" do
      bind = @cms_page.bind_top
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:zh_CN), :zh_CN)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_#{@cms_page.action}_top_zh_CN.html.erb")).should ==
        "<%= ec.shop_name -%>\n<%= ec.shop_mail -%>"
    end

    it "下" do
      bind = @cms_page.bind_bottom
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)
      
      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_bottom_2009082119101338424900.html.erb")).should ==
        "下1テンプレート日本語"
    end

    it "中央テンプレート内容が言語分ない" do
      @cms_page.bind_center.cms_template.content_ko.descriptions = nil
      @cms_page.bind_center.cms_template.content_ko.save!
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:ko), :ko)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_admin_root, 'app', 'views', 'cms', "#{@cms_page.action}_ko.html.erb")).should ==
        %{<% content_for(:layout_top) do -%><%= render(:partial => "cms/show_fashion_top_ko") %><% end -%>} <<
        %{<% content_for(:layout_bottom) do -%><%= render(:partial => "cms/bottom_2009082119101338424900_ko") %><% end -%>} <<
        "夏物入荷しました！！ko\n<%= ec.shop_address -%>\n<%= ec.shop_logo -%>"
    end

    it "下テンプレート内容が言語分ない" do
      @cms_page.bind_bottom.cms_template.content_ko.descriptions = nil
      @cms_page.bind_bottom.cms_template.content_ko.save!
      bind = @cms_page.bind_bottom
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:ko), :ko)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_admin_root, 'app', 'views', 'cms', "_bottom_2009082119101338424900_ko.html.erb")).should ==
        "下1テンプレート日本語"
    end
  end
  
  describe "delete" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_pages"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      @cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles])
      @publish = CmsPublish.create!(
        :target => CmsPublish.target_id_by_key(:production),
        :status_cd => CmsPublish.status_id_by_key(:processing),
        :designated_at => 1.minute.ago,
        :default_template_paths => {})
    end

    it "ビューを削除" do
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      bind.overwrite(file_action)
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == true

      bind.delete(file_action).should
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/models/cms_bind_spec.rb <==
# -*- coding: utf-8 -*-
require File.dirname(__FILE__) + '/../spec_helper'

describe CmsBind do
  fixtures :cms_projects, :cms_pages, :cms_page_titles, 
    :cms_binds, :cms_bind_items, :cms_bind_contents, 
    :cms_templates, :cms_template_contents, :cms_default_templates

  describe "set_bind_name" do
    it 'バインド名をセット' do
      cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles, :cms_project])
      cms_page.bind_center.set_bind_name
      cms_page.bind_center.items.map{|item| item.name}.sort.should == ["おすすめコメント", "店舗住所", "店舗画像"]
    end
  end

  describe "published_filename" do
    describe "cms/show_fashionについて"do
      before(:each) do
        @proj2 = CmsProject.find(2)
        @page = @proj2.pages.find(:first, :conditions => {:controller => 'cms', :action => 'show_fashion'})
      end

      it "中央以外、ページ依存のないテンプレートへのバインド(CmsBindItemがないCmsBind)の場合" do
        bind_bottom = @page.bind_bottom
        bind_bottom.items.should be_empty
        template = bind_bottom.cms_template
        template.should_not be_nil
        template.id.should == 2
        bind_bottom.published_filename(:ja).should     == "cms/_bottom_2009082119101338424900.html.erb"
        bind_bottom.published_filename(:en).should     == "cms/_bottom_2009082119101338424900_en.html.erb"
        bind_bottom.published_filename('zh-CN').should == "cms/_bottom_2009082119101338424900_zh_CN.html.erb"
        bind_bottom.published_filename(:docomo).should   == "cms/_bottom_2009082119101338424900_mobile.html.erb"
        bind_bottom.published_filename(:au).should       == "cms/_bottom_2009082119101338424900_mobile_au.html.erb"
        bind_bottom.published_filename(:softbank).should == "cms/_bottom_2009082119101338424900_mobile_softbank.html.erb"
      end

      it "中央以外、ページ依存のあるテンプレートへのバインド(CmsBindItemを持つCmsBind)の場合" do
        bind_top = @page.bind_top
        bind_top.items.should_not be_empty
        template = bind_top.cms_template
        template.should_not be_nil
        bind_top.published_filename(:ja).should     == "cms/_show_fashion_top.html.erb"
        bind_top.published_filename(:en).should     == "cms/_show_fashion_top_en.html.erb"
        bind_top.published_filename('zh-CN').should == "cms/_show_fashion_top_zh_CN.html.erb"
        bind_top.published_filename(:docomo).should  == "cms/_show_fashion_top_mobile.html.erb"
        bind_top.published_filename(:au).should      == "cms/_show_fashion_top_mobile_au.html.erb"
        bind_top.published_filename(:softbank).should == "cms/_show_fashion_top_mobile_softbank.html.erb"
      end

      it "中央のバインドの場合" do
        bind_center = @page.bind_center
        # bind_center.items.should_not be_empty # itemsの有無はcenterの場合は関係ありません。
        template = bind_center.cms_template
        template.should_not be_nil
        bind_center.published_filename(:ja).should     == "cms/show_fashion.html.erb"
        bind_center.published_filename(:en).should     == "cms/show_fashion_en.html.erb"
        bind_center.published_filename('zh-CN').should == "cms/show_fashion_zh_CN.html.erb"
        bind_center.published_filename(:docomo).should   == "cms/show_fashion_mobile.html.erb"
        bind_center.published_filename(:au).should       == "cms/show_fashion_mobile_au.html.erb"
        bind_center.published_filename(:softbank).should == "cms/show_fashion_mobile_softbank.html.erb"
      end
    end
  end

  describe "filename_map" do
    it "cms/show_fashionについて"do
      @proj2 = CmsProject.find(2)
      @page = @proj2.pages.find(:first, :conditions => {:controller => 'cms', :action => 'show_fashion'})

      # 2009/08/20現在、プロジェクト間で重複するCmsPageは "cms/index"のみ。
      # ただし、オープンされているプロジェクトだけだと重複がないので、全てのステータスを対象にします。
      map = CmsBind.filename_map({:project_status_keys =>[*CmsProject.status_keys]})
      # bottomを利用するページを増やしたため、ファイルの重複が発生しています。よってこのテストはコメントアウトします。
#      map["cms/_bottom_2009082119101338424900.html.erb"      ].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900_en.html.erb"   ].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900_zh_CN.html.erb"].first.id.should == @page.bind_bottom.id
#      map["cms/_bottom_2009082119101338424900.html.erb"      ].last.should == 'ja'
#      map["cms/_bottom_2009082119101338424900_en.html.erb"   ].last.should == 'en'
#      map["cms/_bottom_2009082119101338424900_zh_CN.html.erb"].last.should == 'zh_CN'
      
      map["cms/_show_fashion_top.html.erb"      ].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top_en.html.erb"   ].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top_zh_CN.html.erb"].first.id.should == @page.bind_top.id
      map["cms/_show_fashion_top.html.erb"      ].last.should == 'ja'
      map["cms/_show_fashion_top_en.html.erb"   ].last.should == 'en'
      map["cms/_show_fashion_top_zh_CN.html.erb"].last.should == 'zh_CN'
      
      map["cms/show_fashion.html.erb"      ].first.id.should == @page.bind_center.id
      map["cms/show_fashion_en.html.erb"   ].first.id.should == @page.bind_center.id
      map["cms/show_fashion_zh_CN.html.erb"].first.id.should == @page.bind_center.id
      map["cms/show_fashion.html.erb"      ].last.should == 'ja'
      map["cms/show_fashion_en.html.erb"   ].last.should == 'en'
      map["cms/show_fashion_zh_CN.html.erb"].last.should == 'zh_CN'

      page = CmsPage.find(:first, :conditions => {:controller => 'account', :action => 'login'})
      map["account/login.html.erb"      ].first.id.should == page.bind_center.id
      map["account/login_en.html.erb"   ].first.id.should == page.bind_center.id
      map["account/login_zh_CN.html.erb"].first.id.should == page.bind_center.id
      map["account/login.html.erb"      ].last.should == 'ja'
      map["account/login_en.html.erb"   ].last.should == 'en'
      map["account/login_zh_CN.html.erb"].last.should == 'zh_CN'
    end
  
    it "#786 findのオプションを指定可能にします" do
      CmsBind.should_receive(:find).with(:all, 
        :include => [{:cms_template => :contents}, {:cms_page => :titles}, {:items => :contents}],
        :joins => "inner join cms_pages cond_cms_pages on cond_cms_pages.id = cms_binds.cms_page_id ",
        :conditions => ["(cond_cms_pages.id in (?))", CmsPage.primary_page_ids({:project_status_keys => [:opened]})]).
        and_return([])
      
      file_to_bind_in_opened_projects = CmsBind.filename_map({:project_status_keys =>[:opened], 
        :find_options => {:include => [{:cms_template => :contents}, {:cms_page => :titles}, {:items => :contents}]}})
    end

  end

  describe "overwrite" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_pages"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      @cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles])
      @publish = CmsPublish.create!(
        :target => CmsPublish.target_id_by_key(:production),
        :status_cd => CmsPublish.status_id_by_key(:processing),
        :designated_at => 1.minute.ago,
        :default_template_paths => {:pc => {}, :mobile => {}})
    end

    # TODO モバイルのテストが未実施
    describe "for pc" do
    it "中央" do
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should ==
        '<% content_for(:layout_top) do -%><%= render(:partial => "cms/show_fashion_top") %><% end -%>' <<
        '<% content_for(:layout_bottom) do -%><%= render(:partial => "cms/bottom_2009082119101338424900") %><% end -%>' <<
        "夏物入荷しました！！ja\n<%= ec.shop_address -%>\n<%= ec.shop_logo -%>"
    end

    it "上" do
      bind = @cms_page.bind_top
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:zh_CN), :zh_CN)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_#{@cms_page.action}_top_zh_CN.html.erb")).should ==
        "<%= ec.shop_name -%>\n<%= ec.shop_mail -%>"
    end

    it "下" do
      bind = @cms_page.bind_bottom
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)
      
      IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_bottom_2009082119101338424900.html.erb")).should ==
        "下1テンプレート日本語"
    end

    it "中央テンプレート内容が言語分ない" do
      @cms_page.bind_center.cms_template.content_ko.descriptions = nil
      @cms_page.bind_center.cms_template.content_ko.save!
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:ko), :ko)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_admin_root, 'app', 'views', 'cms', "#{@cms_page.action}_ko.html.erb")).should ==
        %{<% content_for(:layout_top) do -%><%= render(:partial => "cms/show_fashion_top_ko") %><% end -%>} <<
        %{<% content_for(:layout_bottom) do -%><%= render(:partial => "cms/bottom_2009082119101338424900_ko") %><% end -%>} <<
        "夏物入荷しました！！ko\n<%= ec.shop_address -%>\n<%= ec.shop_logo -%>"
    end

    it "下テンプレート内容が言語分ない" do
      @cms_page.bind_bottom.cms_template.content_ko.descriptions = nil
      @cms_page.bind_bottom.cms_template.content_ko.save!
      bind = @cms_page.bind_bottom
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:ko), :ko)
      file_action.targets << bind
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
      bind.overwrite(file_action)

      IO.read(File.join(EcRider.config.ec_admin_root, 'app', 'views', 'cms', "_bottom_2009082119101338424900_ko.html.erb")).should ==
        "下1テンプレート日本語"
      end
    end

    describe "for mobile" do
      it "中央" do
        CmsBindContent.update_all("locale = 'softbank' where locale = 'ja'")
        bind = @cms_page.bind_center
        content = @cms_page.bind_top.cms_template.content_ja
        content.locale = 'softbank'
        content.save!
        content = @cms_page.bind_center.cms_template.content_ja
        content.locale = 'softbank'
        content.save!
        content = @cms_page.bind_bottom.cms_template.content_ja
        content.locale = 'softbank'
        content.save!
        file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename('softbank'), 'softbank')
        file_action.targets << bind
        File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}_mobile_softbank.html.erb")).should == false
        bind.overwrite(file_action)

        IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}_mobile_softbank.html.erb")).should ==
          '<% content_for(:layout_top) do -%><%= render(:partial => "cms/show_fashion_top_mobile_softbank") %><% end -%>' <<
          '<% content_for(:layout_bottom) do -%><%= render(:partial => "cms/bottom_2009082119101338424900_mobile_softbank") %><% end -%>' <<
          "夏物入荷しました！！ja\n<%= ec.shop_address -%>\n<%= ec.shop_logo -%>"
      end

      it "上" do
        bind = @cms_page.bind_top
        content = @cms_page.bind_top.cms_template.content_ja
        content.locale = 'au'
        content.save!
        file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:au), :au)
        file_action.targets << bind
        File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}_mobile_au.html.erb")).should == false
        bind.overwrite(file_action)

        IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_#{@cms_page.action}_top_mobile_au.html.erb")).should ==
          "<%= ec.shop_name -%>\n<%= ec.shop_mail -%>"
      end

      it "下" do
        bind = @cms_page.bind_bottom
        content = @cms_page.bind_bottom.cms_template.content_ja
        content.locale = 'docomo'
        content.save!
        file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename(:docomo), :docomo)
        file_action.targets << bind
        File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}_mobile.html.erb")).should == false
        bind.overwrite(file_action)

        IO.read(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "_bottom_2009082119101338424900_mobile.html.erb")).should ==
          "下1テンプレート日本語"
      end
    end
  end
  
  describe "delete" do
    before(:each) do
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_pages"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'app', 'views', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
      EcRider.config.stub!(:ec_front_root).and_return(tmp_dir)
      @cms_page = CmsPage.find(4, :include => [{:binds => [{:items => :contents}, :cms_template]}, :titles])
      @publish = CmsPublish.create!(
        :target => CmsPublish.target_id_by_key(:production),
        :status_cd => CmsPublish.status_id_by_key(:processing),
        :designated_at => 1.minute.ago,
        :default_template_paths => {:pc => {}, :mobile => {}})
    end

    it "ビューを削除" do
      bind = @cms_page.bind_center
      file_action = CmsPublish::CmsAction.new(@publish, bind.published_filename, 'ja')
      file_action.targets << bind
      bind.overwrite(file_action)
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == true

      bind.delete(file_action).should
      File.exist?(File.join(EcRider.config.ec_front_root, 'app', 'views', 'cms', "#{@cms_page.action}.html.erb")).should == false
    end
  end
end
